@@ -39,6 +39,7 @@ from .type_defs import (
     ExportEBSVolumeRecommendationsResponseTypeDef,
     ExportEC2InstanceRecommendationsResponseTypeDef,
     ExportLambdaFunctionRecommendationsResponseTypeDef,
+    ExternalMetricsPreferenceTypeDef,
     FilterTypeDef,
     GetAutoScalingGroupRecommendationsResponseTypeDef,
     GetEBSVolumeRecommendationsResponseTypeDef,
@@ -113,12 +114,20 @@ class ComputeOptimizerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/compute-optimizer.html#ComputeOptimizer.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client/#close)
+        """
+
     def delete_recommendation_preferences(
         self,
         *,
         resourceType: ResourceTypeType,
         recommendationPreferenceNames: Sequence[RecommendationPreferenceNameType],
-        scope: "ScopeTypeDef" = ...
+        scope: ScopeTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Deletes a recommendation preference, such as enhanced infrastructure metrics.
@@ -131,7 +140,7 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         jobIds: Sequence[str] = ...,
-        filters: Sequence["JobFilterTypeDef"] = ...,
+        filters: Sequence[JobFilterTypeDef] = ...,
         nextToken: str = ...,
         maxResults: int = ...
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
@@ -145,13 +154,13 @@ class ComputeOptimizerClient(BaseClient):
     def export_auto_scaling_group_recommendations(
         self,
         *,
-        s3DestinationConfig: "S3DestinationConfigTypeDef",
+        s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: Sequence[str] = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         fieldsToExport: Sequence[ExportableAutoScalingGroupFieldType] = ...,
         fileFormat: Literal["Csv"] = ...,
         includeMemberAccounts: bool = ...,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
+        recommendationPreferences: RecommendationPreferencesTypeDef = ...
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Auto Scaling groups.
@@ -163,9 +172,9 @@ class ComputeOptimizerClient(BaseClient):
     def export_ebs_volume_recommendations(
         self,
         *,
-        s3DestinationConfig: "S3DestinationConfigTypeDef",
+        s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: Sequence[str] = ...,
-        filters: Sequence["EBSFilterTypeDef"] = ...,
+        filters: Sequence[EBSFilterTypeDef] = ...,
         fieldsToExport: Sequence[ExportableVolumeFieldType] = ...,
         fileFormat: Literal["Csv"] = ...,
         includeMemberAccounts: bool = ...
@@ -180,13 +189,13 @@ class ComputeOptimizerClient(BaseClient):
     def export_ec2_instance_recommendations(
         self,
         *,
-        s3DestinationConfig: "S3DestinationConfigTypeDef",
+        s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: Sequence[str] = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         fieldsToExport: Sequence[ExportableInstanceFieldType] = ...,
         fileFormat: Literal["Csv"] = ...,
         includeMemberAccounts: bool = ...,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
+        recommendationPreferences: RecommendationPreferencesTypeDef = ...
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EC2 instances.
@@ -198,9 +207,9 @@ class ComputeOptimizerClient(BaseClient):
     def export_lambda_function_recommendations(
         self,
         *,
-        s3DestinationConfig: "S3DestinationConfigTypeDef",
+        s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: Sequence[str] = ...,
-        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = ...,
+        filters: Sequence[LambdaFunctionRecommendationFilterTypeDef] = ...,
         fieldsToExport: Sequence[ExportableLambdaFunctionFieldType] = ...,
         fileFormat: Literal["Csv"] = ...,
         includeMemberAccounts: bool = ...
@@ -233,8 +242,8 @@ class ComputeOptimizerClient(BaseClient):
         autoScalingGroupArns: Sequence[str] = ...,
         nextToken: str = ...,
         maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
+        filters: Sequence[FilterTypeDef] = ...,
+        recommendationPreferences: RecommendationPreferencesTypeDef = ...
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
         Returns Auto Scaling group recommendations.
@@ -249,7 +258,7 @@ class ComputeOptimizerClient(BaseClient):
         volumeArns: Sequence[str] = ...,
         nextToken: str = ...,
         maxResults: int = ...,
-        filters: Sequence["EBSFilterTypeDef"] = ...,
+        filters: Sequence[EBSFilterTypeDef] = ...,
         accountIds: Sequence[str] = ...
     ) -> GetEBSVolumeRecommendationsResponseTypeDef:
         """
@@ -265,9 +274,9 @@ class ComputeOptimizerClient(BaseClient):
         instanceArns: Sequence[str] = ...,
         nextToken: str = ...,
         maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         accountIds: Sequence[str] = ...,
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
+        recommendationPreferences: RecommendationPreferencesTypeDef = ...
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
         Returns Amazon EC2 instance recommendations.
@@ -284,7 +293,7 @@ class ComputeOptimizerClient(BaseClient):
         period: int,
         startTime: Union[datetime, str],
         endTime: Union[datetime, str],
-        recommendationPreferences: "RecommendationPreferencesTypeDef" = ...
+        recommendationPreferences: RecommendationPreferencesTypeDef = ...
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
         Returns the projected utilization metrics of Amazon EC2 instance
@@ -317,7 +326,7 @@ class ComputeOptimizerClient(BaseClient):
     def get_enrollment_statuses_for_organization(
         self,
         *,
-        filters: Sequence["EnrollmentFilterTypeDef"] = ...,
+        filters: Sequence[EnrollmentFilterTypeDef] = ...,
         nextToken: str = ...,
         maxResults: int = ...
     ) -> GetEnrollmentStatusesForOrganizationResponseTypeDef:
@@ -334,7 +343,7 @@ class ComputeOptimizerClient(BaseClient):
         *,
         functionArns: Sequence[str] = ...,
         accountIds: Sequence[str] = ...,
-        filters: Sequence["LambdaFunctionRecommendationFilterTypeDef"] = ...,
+        filters: Sequence[LambdaFunctionRecommendationFilterTypeDef] = ...,
         nextToken: str = ...,
         maxResults: int = ...
     ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
@@ -349,7 +358,7 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         resourceType: ResourceTypeType,
-        scope: "ScopeTypeDef" = ...,
+        scope: ScopeTypeDef = ...,
         nextToken: str = ...,
         maxResults: int = ...
     ) -> GetRecommendationPreferencesResponseTypeDef:
@@ -375,9 +384,10 @@ class ComputeOptimizerClient(BaseClient):
         self,
         *,
         resourceType: ResourceTypeType,
-        scope: "ScopeTypeDef" = ...,
+        scope: ScopeTypeDef = ...,
         enhancedInfrastructureMetrics: EnhancedInfrastructureMetricsType = ...,
-        inferredWorkloadTypes: InferredWorkloadTypesPreferenceType = ...
+        inferredWorkloadTypes: InferredWorkloadTypesPreferenceType = ...,
+        externalMetricsPreference: ExternalMetricsPreferenceTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Creates a new recommendation preference or updates an existing recommendation
